@@ -1,5 +1,4 @@
-#ifndef _XT_CONDITION_H
-#define _XT_CONDITION_H
+#pragma once
 
 enum {
 	CONDITION_NAME_LEN = 31,
@@ -12,5 +11,3 @@ struct xt_condition_mtinfo {
 	/* Used internally by the kernel */
 	void *condvar __attribute__((aligned(8)));
 };
-
-#endif /* _XT_CONDITION_H */
