@@ -1,5 +1,4 @@
-#ifndef __IPT_IPP2P_H
-#define __IPT_IPP2P_H
+#pragma once
 #define IPP2P_VERSION "0.10"
 
 enum {
@@ -39,8 +38,5 @@ enum {
 };
 
 struct ipt_p2p_info {
-    int cmd;
-    int debug;
+	int32_t cmd, debug;
 };
-
-#endif //__IPT_IPP2P_H
